@@ -1,6 +1,9 @@
 import pickle
+import re
 from pathlib import Path
 
+from sklearn.base import BaseEstimator, TransformerMixin
+from sklearn.compose import make_column_transformer
 from sklearn.pipeline import Pipeline
 
 from rexify.schema import Schema
@@ -34,8 +37,9 @@ class HasTargetMixin:
 
 
 class Serializable:
-    def save(self, output_dir: str, filename: str):
+    def save(self, output_dir: str, filename: str = None):
         make_dirs(output_dir)
+        filename = filename or self._camel_to_snake_case(self.__name__) + ".pickle"
         output_path = Path(output_dir) / filename
         with open(output_path, "wb") as f:
             pickle.dump(self, f)
@@ -46,6 +50,10 @@ class Serializable:
             feat = pickle.load(f)
         return feat
 
+    @staticmethod
+    def _camel_to_snake_case(name: str):
+        return re.sub(r"(?<!^)(?=[A-Z])", "_", name).lower()
+
 
 class BaseEncoder(HasSchemaMixin):
 
@@ -69,6 +77,19 @@ class BaseEncoder(HasSchemaMixin):
     def as_tuple(self):
         return tuple(self)
 
-    @property
-    def name(self):
-        return self._name
+
+class BaseTransformer(BaseEstimator, TransformerMixin):
+    def __init__(self, transformer: TransformerMixin, target_features: list[str]):
+        super().__init__()
+        self.transformer = transformer
+        self.target_features = target_features
+
+        self._column_transformer = make_column_transformer(
+            (self.transformer, self.target_features),
+        )
+
+    def fit(self, X, y=None, **fit_params):
+        return self
+
+    def transform(self, X):
+        pass
